<?php

namespace Schaffen\Core\Movement\Services;


class SalesOrderValidateService
{

    public $response = [];
    public $id = null;
    public $messages = [];
    public $valid = true;

    public function validar_pedido($values)
    {
        $this->validade_dados_pedido($values);
        $this->validate_itens($values);
        $this->validate_forma_pagamento($values);


        if (!$this->valid) {
            $this->response = [
                'status_code' => 500,
                'id' => $this->id,
                'messages' => $this->messages
            ];
        } else {
            $this->response = [
                'status_code' => 200,
                'id' => $this->id,
                'messages' => ["Success"]
            ];
        }

        return $this->response;
    }


    public function validade_dados_pedido($values)
    {
        if ($values['pes_codigo'] == "") {
            $this->messages[] = "O pes_codigo é obrigatório";
            $this->valid = false;
        }
    }


    public function validate_itens($values)
    {
        $itens = count($values['itens']);
        if ($itens < 1) {
            $this->messages[] = "O pedido deve conter pelo menos 1 item.";
            $this->valid = false;
        } else {
            foreach ($values['itens'] as $key => $item) {
                $i = $key + 1;
                if ($item['pve_codigo'] == "") {
                    $this->messages[] = "O pve_codigo é obrigatório (item $i)";
                    $this->valid = false;
                };
                if ($item['pvi_quantidade'] == "") {
                    $this->messages[] = "O pvi_quantidade é obrigatório (item $i)";
                    $this->valid = false;
                };
                if ($item['pvi_valor_unitario'] == "") {
                    $this->messages[] = "O pvi_valor_unitario é obrigatório (item $i)";
                    $this->valid = false;
                };
                if ($item['pvi_desconto'] == "") {
                    $item['pvi_desconto'] = 0;
                };
            }
        }
    }

    public function validate_forma_pagamento($values)
    {
        $forma_pagamento = count($values['forma_pagamento']);
        if ($forma_pagamento < 1) {
            $this->messages[] = "O pedido deve conter pelo menos uma forma de pagamento.";
            $this->valid = false;
        } else {
            foreach ($values['forma_pagamento'] as $key => $item) {
                $i = $key + 1;
                if ($item['fop_codigo'] == "") {
                    $this->messages[] = "O fop_codigo é obrigatório (forma de pagamento $i)";
                    $this->valid = false;
                };
                if ($item['pvfp_valor'] == "") {
                    $this->messages[] = "O pvfp_valor é obrigatório (forma de pagamento $i)";
                    $this->valid = false;
                };
                if ($item['pvfp_numero_vezes'] == "") {
                    $item['pvfp_numero_vezes'] = 1;
                };
            }
        }
    }
}